import { Bounds, ServerConfig } from "./types";
const env = process.env;

const boundsSet = env.MIN_LAT && env.MIN_LON && env.MAX_LAT && env.MAX_LON;
const boundsIncomplete =
  (env.MIN_LAT || env.MIN_LON || env.MAX_LAT || env.MAX_LON) && !boundsSet;
if (boundsIncomplete)
  throw new Error(
    "MIN_LAT, MIN_LON, MAX_LAT, MAX_LON are not all set, please set them in the environment. See README.md for more information.",
  );
if (!boundsSet) console.warn("Bounds are not set, defaulting to full world.");
const bounds: Bounds | null = boundsSet
  ? {
      minlat: +env.MIN_LAT!,
      minlon: +env.MIN_LON!,
      maxlat: +env.MAX_LAT!,
      maxlon: +env.MAX_LON!,
    }
  : null;
export const config: ServerConfig = {
  clientConfig: {
    tileServerUrl:
      env.TILE_SERVER || "https://tile.openstreetmap.org/{zoom}/{x}/{y}.png",
    attribution:
      env.ATTRIBUTION ||
      "&copy; <a href='https://www.openstreetmap.org/copyright'>OpenStreetMap</a> contributors",
    nominatimUrl: env.NOMINATIM || "https://nominatim.openstreetmap.org",
    bounds,
  },
  userAgent: env.USER_AGENT!,
  overpassUrl: env.OVERPASS || "https://overpass-api.de",
};

if (!config.userAgent)
  throw new Error(
    "USER_AGENT is not set, please set it in the environment. See README.md for more information.",
  );
