export type Position = {
  lat: number;
  lon: number;
};
export type WithId = {
  id: number;
};
export type WithTags = {
  tags: Record<string, string>;
};
export type Bounds = {
  minlat: number;
  minlon: number;
  maxlat: number;
  maxlon: number;
};

export type Node = WithId &
  Position &
  WithTags & {
    type: "node";
  };

export type Way = WithId &
  WithTags & {
    type: "way";
    bounds: Bounds;
    nodes: number[];
    geometry?: Position[];
  };
export type ResponseItem = Node | Way; // | Relation;

export type ClientConfig = {
  tileServerUrl: string;
  attribution: string;
  nominatimUrl: string;
  bounds: Bounds | null;
};
export type ServerConfig = {
  clientConfig: ClientConfig;
  overpassUrl: string;
  userAgent: string;
};

export type ClientInfo = {
  config: ClientConfig;
  latest: string;
};
